@@ -8,10 +8,12 @@ extern crate bincode;
 #[macro_use]
 extern crate byteorder;
 extern crate log;
+extern crate rand;
 
 pub mod codec;
 pub mod stub;
 pub mod proto;
 pub mod client;
 pub mod server;
-pub mod frame;
\ No newline at end of file
+pub mod frame;
+pub mod balance;
\ No newline at end of file
